@@ -123,7 +123,7 @@ def cli():
 		bench_command()
 
 	if cmd_from_sys in bench_command.commands:
-		with execute_cmd(check_for_update=not is_cli_command, command=command, logger=logger):
+		with execute_cmd(check_for_update=is_cli_command, command=command, logger=logger):
 			bench_command()
 
 	if in_bench:
@@ -188,13 +188,13 @@ def change_uid():
 
 
 def app_cmd(bench_path="."):
-	f = get_env_cmd("python*", bench_path=bench_path)
+	f = get_env_cmd("python", bench_path=bench_path)
 	os.chdir(os.path.join(bench_path, "sites"))
 	os.execv(f, [f] + ["-m", "frappe.utils.bench_helper"] + sys.argv[1:])
 
 
 def frappe_cmd(bench_path="."):
-	f = get_env_cmd("python*", bench_path=bench_path)
+	f = get_env_cmd("python", bench_path=bench_path)
 	os.chdir(os.path.join(bench_path, "sites"))
 	os.execv(f, [f] + ["-m", "frappe.utils.bench_helper", "frappe"] + sys.argv[1:])
 
@@ -207,7 +207,7 @@ def get_frappe_commands():
 
 
 def get_frappe_help(bench_path="."):
-	python = get_env_cmd("python*", bench_path=bench_path)
+	python = get_env_cmd("python", bench_path=bench_path)
 	sites_path = os.path.join(bench_path, "sites")
 	try:
 		out = get_cmd_output(
