@@ -79,7 +79,7 @@ def is_valid_frappe_branch(frappe_path: str, frappe_branch: str):
 			raise InvalidRemoteException(f"Invalid frappe path: {frappe_path}") from e
 
 
-def log(message, level=0, no_log=False):
+def log(message, level=0, no_log=False, stderr=False):
 	import bench
 	import bench.cli
 
@@ -96,13 +96,13 @@ def log(message, level=0, no_log=False):
 		bench.LOG_BUFFER.append({"prefix": prefix, "message": message, "color": color})
 
 	if no_log:
-		click.secho(message, fg=color)
+		click.secho(message, fg=color, err=stderr)
 	else:
 		loggers = {2: logger.error, 3: logger.warning}
 		level_logger = loggers.get(level, logger.info)
 
 		level_logger(message)
-		click.secho(f"{prefix}: {message}", fg=color)
+		click.secho(f"{prefix}: {message}", fg=color, err=stderr)
 
 
 def check_latest_version():
@@ -125,7 +125,10 @@ def check_latest_version():
 		local_version = Version(VERSION)
 
 		if pypi_version > local_version:
-			log(f"A newer version of bench is available: {local_version} → {pypi_version}")
+			log(
+				f"A newer version of bench is available: {local_version} → {pypi_version}",
+				stderr=True,
+			)
 
 
 def pause_exec(seconds=10):
@@ -231,7 +234,7 @@ def run_frappe_cmd(*args, **kwargs):
 	from bench.utils.bench import get_env_cmd
 
 	bench_path = kwargs.get("bench_path", ".")
-	f = get_env_cmd("python*", bench_path=bench_path)
+	f = get_env_cmd("python", bench_path=bench_path)
 	sites_dir = os.path.join(bench_path, "sites")
 
 	is_async = not from_command_line
@@ -386,7 +389,7 @@ def get_env_frappe_commands(bench_path=".") -> List:
 	"""
 	from bench.utils.bench import get_env_cmd
 
-	python = get_env_cmd("python*", bench_path=bench_path)
+	python = get_env_cmd("python", bench_path=bench_path)
 	sites_path = os.path.join(bench_path, "sites")
 
 	try:
