@@ -181,11 +181,13 @@ def get_required_deps(org, name, branch, deps="hooks.py"):
 	import base64
 
 	git_api_url = f"https://api.github.com/repos/{org}/{name}/contents/{name}/{deps}"
-	params = {"branch": branch or "develop"}
+	params = {"ref": branch or "develop"}
 	res = requests.get(url=git_api_url, params=params).json()
 
 	if "message" in res:
-		git_url = f"https://raw.githubusercontent.com/{org}/{name}/{params['branch']}/{deps}"
+		git_url = (
+			f"https://raw.githubusercontent.com/{org}/{name}/{params['ref']}/{name}/{deps}"
+		)
 		return requests.get(git_url).text
 
 	return base64.decodebytes(res["content"].encode()).decode()
